@@ -1,4 +1,6 @@
 """ Implementation of mooda """
 from .waterframe import WaterFrame
 from .input import read_nc_emodnet, read_nc, read_nc_imos, read_pkl
-from .util import concat, iplot_location, iplot_timeseries
+from .util import concat, iplot_location, iplot_timeseries, md5
+
+__version__ = '1.2.0'
